@@ -35,7 +35,7 @@
 #include <QSettings>
 #include <QTimer>
 
-static QRegExp CONTENT_DISPOSITION_REGEXP("(=\")(.+)(\";)");
+static QRegExp CONTENT_DISPOSITION_REGEXP("(filename=|filename\\*=UTF-8''|filename\\*= UTF-8'')([^;]+)");
 
 Transfer::Transfer(QObject *parent) :
     TransferItem(parent),
@@ -1270,7 +1270,8 @@ void Transfer::stopWaitTimer() {
 }
 
 void Transfer::startDownload() {
-    Logger::log(QString("Transfer::startDownload(). URL: %1, Method: %2").arg(url()).arg(requestMethod()));
+    Logger::log(QString("Transfer::startDownload(). URL: %1, Method: %2").arg(url()).arg(requestMethod()),
+                Logger::LowVerbosity);
     m_redirects = 0;
     m_metadataSet = false;
     initNetworkAccessManager();
@@ -1284,7 +1285,8 @@ void Transfer::startDownload() {
     }
 
     if (bytesTransferred() > 0) {
-        Logger::log("Transfer::startDownload(). Setting 'Range' header to " + QString::number(bytesTransferred()));
+        Logger::log("Transfer::startDownload(). Setting 'Range' header to " + QString::number(bytesTransferred()),
+                    Logger::MediumVerbosity);
         request.setRawHeader("Range", "bytes=" + QByteArray::number(bytesTransferred()) + "-");
     }
 
@@ -1311,13 +1313,14 @@ void Transfer::startDownload() {
 }
 
 void Transfer::followRedirect(const QUrl &url) {
-    Logger::log("Transfer::followRedirect(): " + url.toString());
+    Logger::log("Transfer::followRedirect(): " + url.toString(), Logger::LowVerbosity);
     m_redirects++;
     initNetworkAccessManager();
     QNetworkRequest request(url);
 
     if (bytesTransferred() > 0) {
-        Logger::log("Transfer::followRedirect(). Setting 'Range' header to " + QString::number(bytesTransferred()));
+        Logger::log("Transfer::followRedirect(). Setting 'Range' header to " + QString::number(bytesTransferred()),
+                    Logger::MediumVerbosity);
         request.setRawHeader("Range", "bytes=" + QByteArray::number(bytesTransferred()) + "-");
     }
     
@@ -1395,13 +1398,14 @@ void Transfer::onCaptchaResponseReported(const QString &) {
 void Transfer::onDownloadRequest(QNetworkRequest request, const QByteArray &method, const QByteArray &data) {
     Logger::log(QString("Transfer::onDownloadRequest(). URL: %1, Method: %2, Data: %3")
                        .arg(request.url().toString())
-                       .arg(QString::fromUtf8(method)).arg(QString::fromUtf8(data)));
+                       .arg(QString::fromUtf8(method)).arg(QString::fromUtf8(data)), Logger::LowVerbosity);
     m_redirects = 0;
     m_metadataSet = false;
     initNetworkAccessManager();
     
     if (bytesTransferred() > 0) {
-        Logger::log("Transfer::startDownload(). Setting 'Range' header to " + QString::number(bytesTransferred()));
+        Logger::log("Transfer::startDownload(). Setting 'Range' header to " + QString::number(bytesTransferred()),
+                    Logger::MediumVerbosity);
         request.setRawHeader("Range", "bytes=" + QByteArray::number(bytesTransferred()) + "-");
     }
 
@@ -1438,21 +1442,24 @@ void Transfer::onWaitRequest(int msecs, bool isLongDelay) {
     }    
 }
 
-void Transfer::onDecaptchaSettingsRequest(const QString &title, const QVariantList &settings, const QByteArray &callback) {
+void Transfer::onDecaptchaSettingsRequest(const QString &title, const QVariantList &settings,
+                                          const QByteArray &callback) {
     m_callback = callback;
     startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateRequestedSettingsTimeout()));
     setRequestedSettings(title, settings);
     setStatus(AwaitingDecaptchaSettingsResponse);
 }
 
-void Transfer::onRecaptchaSettingsRequest(const QString &title, const QVariantList &settings, const QByteArray &callback) {
+void Transfer::onRecaptchaSettingsRequest(const QString &title, const QVariantList &settings,
+                                          const QByteArray &callback) {
     m_callback = callback;
     startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateRequestedSettingsTimeout()));
     setRequestedSettings(title, settings);
     setStatus(AwaitingRecaptchaSettingsResponse);
 }
 
-void Transfer::onServiceSettingsRequest(const QString &title, const QVariantList &settings, const QByteArray &callback) {
+void Transfer::onServiceSettingsRequest(const QString &title, const QVariantList &settings,
+                                        const QByteArray &callback) {
     m_callback = callback;
     startWaitTimer(CAPTCHA_TIMEOUT, SLOT(updateRequestedSettingsTimeout()));
     setRequestedSettings(title, settings);
@@ -1478,13 +1485,8 @@ void Transfer::onServiceError(const QString &errorString) {
 }
 
 void Transfer::onReplyMetaDataChanged() {
-    if (m_metadataSet) {
-        return;
-    }
-    
-    QVariant redirect = m_reply->header(QNetworkRequest::LocationHeader);
-
-    if (!redirect.isNull()) {
+    if ((m_metadataSet) || (m_reply->error() != QNetworkReply::NoError)
+        || (!m_reply->rawHeader("Location").isEmpty())) {
         return;
     }
 
@@ -1494,7 +1496,8 @@ void Transfer::onReplyMetaDataChanged() {
         bytes = m_reply->rawHeader("Content-Length").toLongLong();
     }
 
-    Logger::log("Transfer::onReplyMetadataChanged(): Content-Length: " + QString::number(bytes));
+    Logger::log("Transfer::onReplyMetadataChanged(): Content-Length: " + QString::number(bytes),
+                Logger::MediumVerbosity);
     
     if (bytes > 0) {
         setSize(bytes + bytesTransferred());
@@ -1503,25 +1506,18 @@ void Transfer::onReplyMetaDataChanged() {
     if (bytesTransferred() == 0) {
         // Only set the filename if no data has been written
         const QString contentDisposition =
-        QString::fromUtf8(QByteArray::fromPercentEncoding(m_reply->rawHeader("Content-Disposition")));
+        QString::fromUtf8(QByteArray::fromPercentEncoding(m_reply->rawHeader("Content-Disposition"))).remove('"');
         Logger::log("Transfer::onReplyMetadataChanged(): Content-Disposition: " + contentDisposition);
         
         if ((!contentDisposition.isEmpty()) && (CONTENT_DISPOSITION_REGEXP.indexIn(contentDisposition) != -1)) {
             const QString fileName = CONTENT_DISPOSITION_REGEXP.cap(2);
             
             if (!fileName.isEmpty()) {
+                Logger::log("Transfer::onReplyMetadataChanged(): Found filename: " + fileName, Logger::MediumVerbosity);
                 setFileName(Utils::getSanitizedFileName(fileName));
             }
         }
     }
-
-    if (!openFile()) {
-	m_reply->deleteLater();
-	m_reply = 0;
-	setErrorString(tr("Cannot open file - %1").arg(m_file->errorString()));
-	setStatus(Failed);
-	return;
-    }
     
     m_metadataSet = true;
 }
@@ -1537,7 +1533,7 @@ void Transfer::onReplyReadyRead() {
         return;
     }
 
-    if (m_file->write(m_reply->read(bytes)) == -1) {
+    if ((!openFile()) || (m_file->write(m_reply->read(bytes)) == -1)) {
         m_reply->deleteLater();
 	m_reply = 0;
         setErrorString(tr("Cannot write to file - %1").arg(m_file->errorString()));
@@ -1551,15 +1547,15 @@ void Transfer::onReplyReadyRead() {
 
 void Transfer::onReplyFinished() {
     setSpeed(0);
-    const QVariant redirect = m_reply->header(QNetworkRequest::LocationHeader);
+    const QString redirect = QString::fromUtf8(m_reply->rawHeader("Location"));
 
-    if (!redirect.isNull()) {
+    if (!redirect.isEmpty()) {
 	m_file->close();
         m_reply->deleteLater();
         m_reply = 0;
         
         if (m_redirects < MAX_REDIRECTS) {
-            followRedirect(redirect.toUrl());
+            followRedirect(redirect);
         }
         else {
             setErrorString(tr("Maximum redirects reached"));
@@ -1572,7 +1568,7 @@ void Transfer::onReplyFinished() {
     const QNetworkReply::NetworkError error = m_reply->error();
     const QString errorString = m_reply->errorString();
 
-    if (m_reply->isOpen()) {
+    if ((m_reply->isOpen()) && (error == QNetworkReply::NoError) && (openFile())) {
         const qint64 bytes = m_reply->bytesAvailable();
         
         if ((bytes > 0) && (m_metadataSet)) {
