@@ -19,13 +19,10 @@
 
 #include "transferitem.h"
 #include <QNetworkRequest>
-#include <QPointer>
 #include <QTime>
 #include <QUrl>
 
-class CaptchaDialog;
 class DecaptchaPlugin;
-class PluginSettingsDialog;
 class RecaptchaPlugin;
 class ServicePlugin;
 class QFile;
@@ -38,16 +35,20 @@ class Transfer : public TransferItem
     Q_OBJECT
 
     Q_PROPERTY(QString customCommand READ customCommand WRITE setCustomCommand)
+    Q_PROPERTY(bool customCommandOverrideEnabled READ customCommandOverrideEnabled
+               WRITE setCustomCommandOverrideEnabled)
     Q_PROPERTY(QString downloadPath READ downloadPath WRITE setDownloadPath)
     Q_PROPERTY(QString fileName READ fileName WRITE setFileName)
     Q_PROPERTY(QString filePath READ filePath WRITE setFilePath)
     Q_PROPERTY(QString fileSuffix READ fileSuffix)
     Q_PROPERTY(QByteArray captchaImage READ captchaImage)
     Q_PROPERTY(int captchaTimeout READ captchaTimeout)
+    Q_PROPERTY(QString captchaTimeoutString READ captchaTimeoutString)
     Q_PROPERTY(QString id READ id WRITE setId)
     Q_PROPERTY(QString pluginIconPath READ pluginIconPath)
     Q_PROPERTY(QString pluginId READ pluginId)
     Q_PROPERTY(QString pluginName READ pluginName)
+    Q_PROPERTY(bool usePlugins READ usePlugins WRITE setUsePlugins)
     Q_PROPERTY(Priority priority READ priority WRITE setPriority)
     Q_PROPERTY(QString priorityString READ priorityString)
     Q_PROPERTY(int progress READ progress)
@@ -56,8 +57,13 @@ class Transfer : public TransferItem
     Q_PROPERTY(qint64 size READ size)
     Q_PROPERTY(int speed READ speed)
     Q_PROPERTY(QString speedString READ speedString)
+    Q_PROPERTY(QString postData READ postData WRITE setPostData)
+    Q_PROPERTY(QVariantMap requestHeaders READ requestHeaders WRITE setRequestHeaders)
+    Q_PROPERTY(QString requestMethod READ requestMethod WRITE setRequestMethod)
     Q_PROPERTY(QVariantList requestedSettings READ requestedSettings)
     Q_PROPERTY(int requestedSettingsTimeout READ requestedSettingsTimeout)
+    Q_PROPERTY(QString requestedSettingsTimeoutString READ requestedSettingsTimeoutString)
+    Q_PROPERTY(QString requestedSettingsTitle READ requestedSettingsTitle)
     Q_PROPERTY(Status status READ status)
     Q_PROPERTY(QString statusString READ statusString)
     Q_PROPERTY(QString errorString READ errorString)
@@ -82,6 +88,8 @@ public:
 
     QString customCommand() const;
     void setCustomCommand(const QString &c);
+    bool customCommandOverrideEnabled() const;
+    void setCustomCommandOverrideEnabled(bool enabled);
     
     QString downloadPath() const;
     void setDownloadPath(const QString &p);
@@ -94,14 +102,19 @@ public:
 
     QByteArray captchaImage() const;
     int captchaTimeout() const;
+    QString captchaTimeoutString() const;
+    
+    QString iconPath() const;
 
     QString id() const;
     void setId(const QString &i);
-
+    
     QString pluginIconPath() const;
     QString pluginId() const;
     QString pluginName() const;
-
+    bool usePlugins() const;
+    void setUsePlugins(bool enabled);
+    
     Priority priority() const;
     void setPriority(Priority p);
     QString priorityString() const;
@@ -112,9 +125,19 @@ public:
     qint64 size() const;
     int speed() const;
     QString speedString() const;
+    
+    QString postData() const;
+    void setPostData(const QString &data);
+    
+    QVariantMap requestHeaders() const;
+    void setRequestHeaders(const QVariantMap &headers);
+    QString requestMethod() const;
+    void setRequestMethod(const QString &method);
 
     QVariantList requestedSettings() const;
     int requestedSettingsTimeout() const;
+    QString requestedSettingsTimeoutString() const;
+    QString requestedSettingsTitle() const;
 
     Status status() const;
     QString statusString() const;
@@ -139,6 +162,8 @@ public Q_SLOTS:
     bool submitSettingsResponse(const QVariantMap &settings);
 
 private Q_SLOTS:
+    void updateCaptchaTimeout();
+    void updateRequestedSettingsTimeout();
     void updateSpeed();
     void updateWaitTime();
     
@@ -172,7 +197,7 @@ private:
     void setSize(qint64 s);
     void setSpeed(int s);
 
-    void setRequestedSettings(const QVariantList &settings);
+    void setRequestedSettings(const QString &title, const QVariantList &settings);
     void clearRequestedSettings();
 
     void setStatus(Status s);
@@ -189,13 +214,12 @@ private:
     bool openBuffer(const QByteArray &data);
     bool openFile();
 
-    void openCaptchaDialog(const QImage &image);
-
     void startSpeedTimer();
-    void startWaitTimer();
+    void startWaitTimer(int msecs, const char* slot);
     void stopSpeedTimer();
     void stopWaitTimer();
 
+    void startDownload();
     void followRedirect(const QUrl &url);
 
     void deleteFile();
@@ -209,9 +233,6 @@ private:
     QFile *m_file;
     QTimer *m_timer;
 
-    QPointer<CaptchaDialog> m_captchaDialog;
-    QPointer<PluginSettingsDialog> m_settingsDialog;
-
     QString m_customCommand;
     QString m_downloadPath;
     QString m_fileName;
@@ -228,6 +249,11 @@ private:
 
     Status m_status;
 
+    QString m_postData;
+    QString m_requestMethod;
+    
+    QVariantMap m_requestHeaders;
+    
     QString m_url;
 
     QString m_decaptchaPluginId;
@@ -242,16 +268,19 @@ private:
     QString m_recaptchaKey;
     QString m_decaptchaId;
 
+    QString m_requestedSettingsTitle;
     QVariantList m_requestedSettings;
 
     QByteArray m_callback;
-
+    
+    bool m_customCommandOverrideEnabled;
+    bool m_usePlugins;
     bool m_reportCaptchaError;
     bool m_metadataSet;
     bool m_deleteFiles;
 
     int m_redirects;
-    int m_waitTime;
+    int m_timeRemaining;
 };
     
 #endif // TRANSFER_H
