@@ -36,6 +36,7 @@ public:
         insert(TransferItem::CustomCommandOverrideEnabledRole, "customCommandOverrideEnabled");
         insert(TransferItem::DownloadPathRole, "downloadPath");
         insert(TransferItem::ErrorStringRole, "errorString");
+        insert(TransferItem::ExpandedRole, "expanded");
         insert(TransferItem::FileNameRole, "fileName");
         insert(TransferItem::FilePathRole, "filePath");
         insert(TransferItem::IdRole, "id");
@@ -75,6 +76,7 @@ QHash<int, QByteArray> TransferItem::roles = TransferItemRoleNames();
 
 TransferItem::TransferItem(QObject *parent) :
     QObject(parent),
+    m_expanded(false),
     m_row(-1),
     m_parentItem(0)
 {
@@ -108,6 +110,7 @@ QString TransferItem::statusString(TransferItem::Status status) {
     case Paused:
         return tr("Paused");
     case Canceled:
+    case CanceledAndDeleted:
         return tr("Canceled");
     case Failed:
         return tr("Failed");
@@ -162,6 +165,8 @@ QVariant TransferItem::data(int role) const {
         return canPause();
     case CanStartRole:
         return canStart();
+    case ExpandedRole:
+        return expanded();
     case ItemTypeRole:
         return itemType();
     case ItemTypeStringRole:
@@ -179,8 +184,14 @@ QVariant TransferItem::data(const QByteArray &roleName) const {
     return data(roles.key(roleName));
 }
 
-bool TransferItem::setData(int, const QVariant &) {
-    return false;
+bool TransferItem::setData(int role, const QVariant &value) {
+    switch (role) {
+    case ExpandedRole:
+        setExpanded(value.toBool());
+        return true;
+    default:
+        return false;
+    }
 }
 
 bool TransferItem::setData(const QByteArray &roleName, const QVariant &value) {
@@ -192,6 +203,7 @@ QMap<int, QVariant> TransferItem::itemData() const {
     map[CanCancelRole] = canCancel();
     map[CanPauseRole] = canPause();
     map[CanStartRole] = canStart();
+    map[ExpandedRole] = expanded();
     map[ItemTypeRole] = itemType();
     map[ItemTypeStringRole] = itemTypeString();
     map[RowRole] = row();
@@ -204,6 +216,7 @@ QVariantMap TransferItem::itemDataWithRoleNames() const {
     map[roles.value(CanCancelRole)] = canCancel();
     map[roles.value(CanPauseRole)] = canPause();
     map[roles.value(CanStartRole)] = canStart();
+    map[roles.value(ExpandedRole)] = expanded();
     map[roles.value(ItemTypeRole)] = itemType();
     map[roles.value(ItemTypeStringRole)] = itemTypeString();
     map[roles.value(RowRole)] = row();
@@ -264,6 +277,17 @@ QString TransferItem::itemTypeString() const {
     }
 }
 
+bool TransferItem::expanded() const {
+    return m_expanded;
+}
+
+void TransferItem::setExpanded(bool enabled) {
+    if (enabled != expanded()) {
+        m_expanded = enabled;
+        emit dataChanged(this, ExpandedRole);
+    }
+}
+
 int TransferItem::row() const {
     return m_row;
 }
