@@ -18,11 +18,13 @@
 #include "aboutdialog.h"
 #include "actionmodel.h"
 #include "addurlsdialog.h"
+#include "captchadialog.h"
 #include "categories.h"
 #include "clipboardurlsdialog.h"
 #include "decaptchapluginmanager.h"
 #include "definitions.h"
 #include "packagepropertiesdialog.h"
+#include "pluginsettingsdialog.h"
 #include "qdl.h"
 #include "recaptchapluginmanager.h"
 #include "retrieveurlsdialog.h"
@@ -262,6 +264,8 @@ MainWindow::MainWindow(QWidget *parent) :
 
     connect(Settings::instance(), SIGNAL(nextActionChanged(int)), m_actionSelector, SLOT(setCurrentIndex(int)));
     
+    connect(TransferModel::instance(), SIGNAL(captchaRequest(TransferItem*)), this, SLOT(showCaptchaDialog(TransferItem*)));
+    connect(TransferModel::instance(), SIGNAL(settingsRequest(TransferItem*)), this, SLOT(showPluginSettingsDialog(TransferItem*)));
     connect(TransferModel::instance(), SIGNAL(activeTransfersChanged(int)), this, SLOT(onActiveTransfersChanged(int)));
     connect(TransferModel::instance(), SIGNAL(totalSpeedChanged(int)), this, SLOT(onTotalSpeedChanged(int)));
 
@@ -523,9 +527,15 @@ void MainWindow::showAddUrlsDialog() {
         const QStringList urls = addDialog.urls();
 
         if (!urls.isEmpty()) {
-            UrlCheckDialog checkDialog(this);
-            checkDialog.addUrls(urls);
-            checkDialog.exec();
+            if (addDialog.usePlugins()) {
+                UrlCheckDialog checkDialog(this);
+                checkDialog.addUrls(urls);
+                checkDialog.exec();
+            }
+            else {
+                TransferModel::instance()->append(urls, addDialog.requestMethod(), addDialog.requestHeaders(),
+                                                  addDialog.postData());
+            }
         }
     }
 }
@@ -556,9 +566,15 @@ void MainWindow::showImportUrlsDialog() {
             const QStringList urls = addDialog.urls();
 
             if (!urls.isEmpty()) {
-                UrlCheckDialog checkDialog(this);
-                checkDialog.addUrls(urls);
-                checkDialog.exec();
+                if (addDialog.usePlugins()) {
+                    UrlCheckDialog checkDialog(this);
+                    checkDialog.addUrls(urls);
+                    checkDialog.exec();
+                }
+                else {
+                    TransferModel::instance()->append(urls, addDialog.requestMethod(), addDialog.requestHeaders(),
+                                                      addDialog.postData());
+                }
             }
         }
     }
@@ -569,6 +585,7 @@ void MainWindow::showRetrieveUrlsDialog() {
 
     if (dialog.exec() == QDialog::Accepted) {
         const QStringList results = dialog.results();
+        dialog.clear();
 
         if (!results.isEmpty()) {
             showAddUrlsDialog(results);
@@ -582,7 +599,8 @@ void MainWindow::showRetrieveUrlsDialog(const QStringList &urls) {
 
     if (dialog.exec() == QDialog::Accepted) {
         const QStringList results = dialog.results();
-
+        dialog.clear();
+        
         if (!results.isEmpty()) {
             showAddUrlsDialog(results);
         }
@@ -614,6 +632,56 @@ void MainWindow::showAboutDialog() {
     AboutDialog(this).exec();
 }
 
+void MainWindow::showCaptchaDialog(TransferItem *t) {
+    QPointer<TransferItem> transfer(t);
+    CaptchaDialog dialog(this);
+    dialog.setImage(QImage::fromData(QByteArray::fromBase64(transfer->data(TransferItem::CaptchaImageRole).toByteArray())));
+    dialog.setTimeout(transfer->data(TransferItem::CaptchaTimeoutRole).toInt());
+    connect(transfer, SIGNAL(finished(TransferItem*)), &dialog, SLOT(close()));
+    
+    switch (dialog.exec()) {
+    case QDialog::Accepted:
+        if (transfer) {
+            transfer->setData(TransferItem::CaptchaImageRole, dialog.response());
+        }
+        
+        break;
+    case QDialog::Rejected:
+        if (transfer) {
+            transfer->setData(TransferItem::CaptchaImageRole, QString());
+        }
+        
+        break;
+    default:
+        break;
+    }
+}
+
+void MainWindow::showPluginSettingsDialog(TransferItem *t) {
+    QPointer<TransferItem> transfer(t);
+    PluginSettingsDialog dialog(transfer->data(TransferItem::RequestedSettingsRole).toList(), this);
+    dialog.setWindowTitle(transfer->data(TransferItem::RequestedSettingsTitleRole).toString());
+    dialog.setTimeout(transfer->data(TransferItem::RequestedSettingsTimeoutRole).toInt());
+    connect(transfer, SIGNAL(finished(TransferItem*)), &dialog, SLOT(close()));
+    
+    switch (dialog.exec()) {
+    case QDialog::Accepted:
+        if (transfer) {
+            transfer->setData(TransferItem::RequestedSettingsRole, dialog.settings());
+        }
+        
+        break;
+    case QDialog::Rejected:
+        if (transfer) {
+            transfer->setData(TransferItem::RequestedSettingsRole, QVariant());
+        }
+        
+        break;
+    default:
+        break;
+    }
+}
+
 void MainWindow::loadPlugins() {
     const int count = DecaptchaPluginManager::instance()->load() + RecaptchaPluginManager::instance()->load()
                       + ServicePluginManager::instance()->load();
