@@ -32,7 +32,6 @@ class JavaScriptRecaptchaPlugin : public RecaptchaPlugin
     Q_PROPERTY(QString id READ id)
 
 public:
-    explicit JavaScriptRecaptchaPlugin(QObject *parent = 0);
     explicit JavaScriptRecaptchaPlugin(const QString &id, const QString &fileName, QObject *parent = 0);
 
     QString fileName() const;
@@ -40,6 +39,8 @@ public:
     QString id() const;
 
     virtual RecaptchaPlugin* createPlugin(QObject *parent = 0);
+    
+    virtual void setNetworkAccessManager(QNetworkAccessManager *manager);
 
 public Q_SLOTS:
     virtual bool cancelCurrentOperation();
@@ -55,7 +56,9 @@ private Q_SLOTS:
 private:
     void initEngine();
     
+    JavaScriptPluginGlobalObject *m_global;
     QScriptEngine *m_engine;
+    QPointer<QNetworkAccessManager> m_nam;
 
     QString m_fileName;
     QString m_id;
