@@ -32,7 +32,6 @@ class JavaScriptServicePlugin : public ServicePlugin
     Q_PROPERTY(QString id READ id)
 
 public:
-    explicit JavaScriptServicePlugin(QObject *parent = 0);
     explicit JavaScriptServicePlugin(const QString &id, const QString &fileName, QObject *parent = 0);
 
     QString fileName() const;
@@ -40,7 +39,9 @@ public:
     QString id() const;
 
     virtual ServicePlugin* createPlugin(QObject *parent = 0);
-
+    
+    virtual void setNetworkAccessManager(QNetworkAccessManager *manager);
+    
 public Q_SLOTS:
     virtual bool cancelCurrentOperation();
     
@@ -60,7 +61,9 @@ private Q_SLOTS:
 private:
     void initEngine();
     
+    JavaScriptPluginGlobalObject *m_global;
     QScriptEngine *m_engine;
+    QPointer<QNetworkAccessManager> m_nam;
 
     QString m_fileName;
     QString m_id;
