@@ -21,6 +21,7 @@
 #include "concurrenttransfersmodel.h"
 #include "decaptchapluginconfigmodel.h"
 #include "definitions.h"
+#include "logger.h"
 #include "maskeditem.h"
 #include "networkproxytypemodel.h"
 #include "package.h"
@@ -34,6 +35,7 @@
 #include "transfer.h"
 #include "transferitemprioritymodel.h"
 #include "transfermodel.h"
+#include "transferlistmodel.h"
 #include "urlactionmodel.h"
 #include "urlcheckmodel.h"
 #include "urlretrievalmodel.h"
@@ -51,6 +53,7 @@ void registerTypes() {
     qmlRegisterType<CategorySelectionModel>("Qdl", 2, 0, "CategorySelectionModel");
     qmlRegisterType<ConcurrentTransfersModel>("Qdl", 2, 0, "ConcurrentTransfersModel");
     qmlRegisterType<DecaptchaPluginConfigModel>("Qdl", 2, 0, "DecaptchaPluginConfigModel");
+    qmlRegisterType<LoggerVerbosityModel>("Qdl", 2, 0, "LoggerVerbosityModel");
     qmlRegisterType<MaskedItem>("Qdl", 2, 0, "MaskedItem");
     qmlRegisterType<NetworkProxyTypeModel>("Qdl", 2, 0, "NetworkProxyTypeModel");
     qmlRegisterType<PluginSettings>("Qdl", 2, 0, "PluginSettings");
@@ -60,6 +63,7 @@ void registerTypes() {
     qmlRegisterType<ServicePluginConfigModel>("Qdl", 2, 0, "ServicePluginConfigModel");
     qmlRegisterType<ServiceSelectionModel>("Qdl", 2, 0, "ServiceSelectionModel");
     qmlRegisterType<TransferItemPriorityModel>("Qdl", 2, 0, "TransferItemPriorityModel");
+    qmlRegisterType<TransferListModel>("Qdl", 2, 0, "TransferListModel");
     qmlRegisterType<UrlActionModel>("Qdl", 2, 0, "UrlActionModel");
     
     qmlRegisterUncreatableType<Package>("Qdl", 2, 0, "Package", "");
@@ -89,14 +93,19 @@ Q_DECL_EXPORT int main(int argc, char *argv[]) {
     QScopedPointer<UrlCheckModel> checker(UrlCheckModel::instance());
     QScopedPointer<UrlRetrievalModel> retriever(UrlRetrievalModel::instance());
     
+    Logger logger;
     Utils utils;
     
     registerTypes();
+    Logger::setFileName(Settings::loggerFileName());
+    Logger::setVerbosity(Settings::loggerVerbosity());
+    Settings::setNetworkProxy();
     
     QDeclarativeView view;
     QDeclarativeContext *context = view.rootContext();
     context->setContextProperty("categories", categories.data());
     context->setContextProperty("decaptchaPluginManager", decaptchaManager.data());
+    context->setContextProperty("logger", &logger);
     context->setContextProperty("qdl", qdl.data());
     context->setContextProperty("recaptchaPluginManager", recaptchaManager.data());
     context->setContextProperty("servicePluginManager", serviceManager.data());
